@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.108-3-gd14d81b
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.109-3-g16f93e6
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.109';
+our $VERSION = '0.110';
 
 use Moose;
 with
@@ -261,7 +261,7 @@ sub configure
         [ 'MetaProvides::Package' => { ':version' => '1.15000002', finder => ':InstallModules', meta_noindex => 1, inherit_version => 0, inherit_missing => 0 } ],
         'MetaConfig',
         [ 'Keywords'            => { ':version' => '0.004' } ],
-        [ 'Git::Contributors'   => { ':version' => '0.004', order_by => 'commits' } ],
+        # [Git::Contributors]
         # [StaticInstall]
 
         # Register Prereqs
@@ -281,6 +281,9 @@ sub configure
         # Install Tool (some are also Test Runners)
         $self->installer,   # options are set lower down, via %extra_args
 
+        # we prefer this to run after other Register Prereqs plugins
+        [ 'Git::Contributors'   => { ':version' => '0.004', order_by => 'commits' } ],
+
         # note that MBT::*'s static tweak is consequently adjusted, later
         [ 'StaticInstall' => { ':version' => '0.005', mode => $static_install_mode, dry_run => $static_install_dry_run } ],
 
@@ -446,7 +449,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.109
+version 0.110
 
 =head1 SYNOPSIS
 
@@ -627,10 +630,8 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [MetaConfig]
     [Keywords]
     :version = 0.004
-    [Git::Contributors]
-    :version = 0.004
-    order_by = commits
-    ;[StaticInstall]   ; below
+    ;[Git::Contributors]    ; below
+    ;[StaticInstall]        ; below
 
 
     ;;; Register Prereqs
@@ -655,6 +656,10 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     ;;; Install Tool
     <specified installer(s)>
 
+    [Git::Contributors]
+    :version = 0.004
+    order_by = commits
+
     [StaticInstall]
     :version = 0.005
     mode = auto
@@ -815,7 +820,8 @@ otherwise the version is incremented after each release, in the F<*.pm> files.
 
 =head2 pod coverage
 
-Subs can be considered "covered" for pod coverage tests by adding a directive to pod,
+Subroutines can be considered "covered" for pod coverage tests by adding a
+directive to pod (as many as you'd like),
 as described in L<Pod::Coverage::TrustPod>:
 
     =for Pod::Coverage foo bar baz
@@ -870,7 +876,7 @@ C<< installer = =inc::Foo >> (if no configs are needed for this plugin; e.g. sub
 
 =item *
 
-C<< installer = none >> (if you are including your own later on, with configs)
+C<< installer = none >> (if you are providing your own elsewhere in the file, with configs)
 
 =back
 
